// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.provider.azure.util;

import com.auth0.jwt.JWT;
import com.auth0.jwt.interfaces.DecodedJWT;
import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.notification.provider.interfaces.IServiceAccountValidator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class AzureServiceAccountValidatorImpl implements IServiceAccountValidator {

    private final static String APP_ID_CLAIM = "appid";

    @Autowired
    AppProperties appProperties;

    @Autowired
    JaxRsDpsLog logger;

    @Override
    public boolean isValidPublisherServiceAccount(String token) {
        return isValidServiceAccount(token, this.appProperties.getEventGridId());
    }

    @Override
    public boolean isValidServiceAccount(String token, String userIdentity, String... audiences) {
        DecodedJWT jwt = JWT.decode(token);

        String appIdClaim = jwt.getClaim(APP_ID_CLAIM).asString();

        if(appIdClaim!= null && appIdClaim.equals(userIdentity)) {
            logger.debug("PubSub authorized");
            return true;
        }
        return false;
    }
}
