package org.opengroup.osdu.notification.provider.azure.messageBus.thread;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.MockitoAnnotations;
import org.mockito.junit.MockitoJUnitRunner;
import org.opengroup.osdu.core.common.cryptographic.HmacData;
import org.opengroup.osdu.core.common.cryptographic.SignatureServiceException;

import java.util.Base64;

import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
import static org.junit.jupiter.api.Assertions.assertNotNull;

@RunWith(MockitoJUnitRunner.class)
public class ThreadSignatureServiceTest {

    private static final String URL = "http://www.osdu.example.com/signature";
    private static final String SECRET = "93491ab4453ef0306bf08f3703460950";

    @InjectMocks
    private ThreadSignatureService threadSignatureService;

    @Before
    public void setUp() {
        MockitoAnnotations.openMocks(ThreadSignatureServiceTest.this);
    }

    @Test
    public void getSignedSignatureTest() {
        assertDoesNotThrow(() -> {
            String actual = threadSignatureService.getSignedSignature(URL, SECRET);
            assertNotNull(actual);
        });
    }

    @Test
    public void getSignedSignatureTest_withExpiryTimeAndNonce() {
        assertDoesNotThrow(() -> {
            String actual = threadSignatureService.getSignedSignature(URL, SECRET, String.valueOf(System.currentTimeMillis() + 120000), SECRET);
            assertNotNull(actual);
        });
    }

    @Test(expected = SignatureServiceException.class)
    public void getSignedSignatureTest_withExpiryTimeAndNonce_signatureServiceException() throws SignatureServiceException {
        threadSignatureService.getSignedSignature(URL, "", String.valueOf(System.currentTimeMillis() + 120000), SECRET);
    }

    @Test
    public void verifyHmacSignature() throws SignatureServiceException {
        String expireTime = String.valueOf(System.currentTimeMillis() + 120000L);

        HmacData hmacData = new HmacData();
        hmacData.setExpireMillisecond(expireTime);
        hmacData.setNonce(SECRET);
        hmacData.setEndpointUrl(URL);
        String signature = threadSignatureService.getSignedSignature(URL, SECRET, expireTime, SECRET);
        assertDoesNotThrow(() ->
                threadSignatureService.verifyHmacSignature(
                        String.format("%s.%s", Base64.getEncoder().encodeToString(new ObjectMapper().writeValueAsBytes(hmacData)), signature), SECRET)
        );
    }

    @Test(expected = SignatureServiceException.class)
    public void verifyHmacSignature_whenHmacIsNullOrEmpty_thenThrowSignatureServiceException() throws SignatureServiceException {
        threadSignatureService.verifyHmacSignature("", SECRET);
    }

    @Test(expected = SignatureServiceException.class)
    public void verifyHmacSignature_whenSecretIsNullOrEmpty_thenThrowSignatureServiceException() throws SignatureServiceException {
        threadSignatureService.verifyHmacSignature(URL, "");
    }
}